from fantasynames.hobbit import hobbit
from fantasynames.elf import elf
from fantasynames.french import french
from fantasynames.anglo import anglo
from fantasynames.dwarf import dwarf
from fantasynames.human_diverse import human



from fantasynames.data import hobbit_data
from fantasynames.language import Language


class Hobbit(Language):
    transformations = hobbit_data["transformations"]

    @classmethod
    def _name1_male(cls) -> str:
        cols = [hobbit_data["name1_col1"], hobbit_data["name1_male_suffixes"]]
        return cls._name_from_lists(cols)

    @classmethod
    def _name1_female(cls) -> str:
        cols = [hobbit_data["name1_col1"], hobbit_data["name1_female_suffixes"]]
        return cls._name_from_lists(cols)

    @classmethod
    def _name2(cls) -> str:
        cols = [hobbit_data["name2_col1"], hobbit_data["name2_col2"]]
        name = cls._name_from_lists(cols)
        return name


hobbit = Hobbit.name



import typing as t

"""
In this file, we store the various string arrays from which names are generated.
"""

hobbit_data: t.Dict[str, t.List] = {
    "name1_col1": [
        "BVB",
        "mVB",
        "frVB",
        "flVB",
        "wVB",
        "lVB",
        "BVm",
        "bilb",
        "BarB",
        "mar",
    ],
    "name1_female_suffixes": ["*a", "*y", "*ia", "lia", "ina", "emina"],
    "name1_male_suffixes": [
        "*o",
        "*y",
        "*ly",
        "*in",
        "win",
        "ius",
        "lius",
        "nus",
    ],
    "name2_col1": [
        "berry",
        "sweet",
        "milk",
        "honey",
        "crumble",
        "jiggle",
        "purple",
        "sneaky",
        "hungry",
        "rumble",
        "prickle",
        "butter",
        "long",
        "short",
        "old",
        "fresh",
        "apple",
        "poppy",
        "fish",
        "cream",
        "wimble",
        "hope",
        "smoke",
        "fiddle",
        "tickle",
        "bubble",
    ],
    "name2_col2": [
        "muffins",
        "cakes",
        "belly",
        "foot",
        "bum",
        "finger",
        "burrow",
        "toe",
        "tum",
        "weed",
        "scone",
        "biscuits",
        "candles",
        "treats",
        "crust",
        "tart",
        "pipe",
        "feet",
        "wort",
        "sticks",
        "stack",
        "thorp",
    ],
    "transformations": [
        {"input": "B", "outputs": ["t", "d", "b", "p"]},
        {"input": "V", "outputs": ["i", "o", "a", "u"]},
    ],
}

elf_data: t.Dict[str, t.List] = {
    "name1_col1": [
        "RA",
        "gA",
        "gE",
        "ei",
        "ai",
        "ie",
        "gwE",
        "thE",
        "A",
        "E",
        "fA",
        "cA",
    ],
    "name1_col2": ["drAl", "thAn", "vAl", "rAth", "thAr", "rAn", "rAl", "nAl"],
    "name1_suffixes": ["a", "ia", "on", "ys"],
    "name2_col2": [
        "Nther",
        "Nion",
        "Nonus",
        "Niath",
        "Naire",
        "Nuth",
        "Neus",
        "Naine",
        "viel",
    ],
    "transformations": [
        {"input": "A", "outputs": ["a", "a", "e", "e", "ia", "ea", "y"]},
        {"input": "E", "outputs": ["a", "e"]},
        {"input": "N", "outputs": ["n", "m", "l", "r"]},
        {"input": "R", "outputs": ["l", "r"]},
        {"input": "M", "outputs": ["n", "m"]},
    ],
}

dwarf_data: t.Dict[str, t.List] = {
    "name1_col1": [
        "TOrN",
        "TOR",
        "thOR",
        "thOrN",
        "ing",
        "hOR",
        "ein",
        "lOrg",
        "ROT",
        "TrOn",
        "hOT",
        "bOr",
    ],
    "name1_col2": [
        "gIRD",
        "hIRD",
        "vIRD",
        "rOm",
        "mAr",
        "nAr",
        "mIr",
        "nIr",
        "An",
        "vAR",
        "muiR",
        "ean",
    ],
    "name1_suffixes": ["a", "ig", "aid", "et", "ja", "is", "ssi"],
    "transformations": [
        {"input": "A", "outputs": ["i", "a", "o", "u"]},  # any vowel
        {"input": "I", "outputs": ["i", "e"]},  # front vowels
        {"input": "O", "outputs": ["o", "u"]},  # back vowels
        {"input": "R", "outputs": ["l", "r"]},  # liquids
        {"input": "T", "outputs": ["t", "d", "th"]},  # alveolar obstruents
        {"input": "D", "outputs": ["t", "d"]},  # alveolar stops
    ],
}

human_data: t.Dict[str, t.List] = {
    "name1_col1": [
        "AR",
        "kAR",
        "kAs",
        "rAd",
        "AvIn",
        "brAn",
        "dAn",
        "AlIn",
        "frIn",
        "gAn",
        "hAR",
        "sIg",
        "sAn",
        "tIm",
        "sAm",
        "bIn",
    ],
    "name1_col2": [
        "tAn",
        "RAm",
        "dAn",
        "wArd",
        "nAr",
        "wAll",
        "rAth",
        "ric",
        "rett",
        "lyn",
        "mAnd",
        "der",
    ],
    "name1_suffixes": ["a", "ia", "ie", "ise", "ise", "isa"],
    "name2_col1": [
        "white",
        "red",
        "black",
        "grey",
        "west",
        "east",
        "fair",
        "rose",
        "grave",
        "wood",
        "daven",
        "ast",
        "avon",
        "bal",
        "bex",
        "blen",
        "brad",
        "row",
        "car",
        "cul",
        "dal",
        "dun",
        "dry",
        "fin",
        "gart",
        "gil",
        "glen",
        "kil",
        "king",
        "kirk",
        "knock",
        "lang",
        "lock",
        "lind",
        "nor",
        "pen",
        "pit",
        "pol",
        "pont",
        "ply",
        "strat",
        "stan",
        "swin",
        "tarn",
        "win",
        "wel",
        "roy",
        "grim",
        "mor",
    ],
    "name2_col2": [
        "beck",
        "berg",
        "berry",
        "bury",
        "burgh",
        "bourne",
        "burn",
        "cott",
        "den",
        "firth",
        "ham",
        "holme",
        "hurst",
        "ing",
        "low",
        "lyn",
        "mere",
        "more",
        "pool",
        "shaw",
        "stead",
        "ster",
        "stow",
        "ton",
        "ward",
        "wick",
        "wich",
        "worth",
        "field",
        "ford",
        "hill",
        "dale",
        "fell",
        "shire",
        "stein",
        "rock",
        "mill",
        "bridge",
        "son",
        "bluff",
    ],
    "transformations": [
        {"input": "I", "outputs": ["i", "e", "y"]},
        {"input": "A", "outputs": ["i", "a", "o", "u", "e"]},
        {"input": "R", "outputs": ["l", "r"]},
        {"input": "N", "outputs": ["n", "m"]},
    ],
}

french_data: t.Dict[str, t.List] = {
    "name1_col1": [
        "IN",
        "IB",
        "Il",
        "aB",
        "Is",
        "RuB",
        "RIB",
        "sIB",
        "arn",
        "auB",
        "clIB",
        "BIR",
    ],
    "name1_col2": ["is", "En", "Ant", "And", "ieR", "el", "Irt", "ois", "et", "ert"],
    "name1_female_suffixes": [
        "*a",
        "ia",
        "*e",
    ],
    "name2_col1": [
        "nI",
        "vI",
        "rou",
        "for",
        "bAr",
        "clar",
        "lIv",
        "lI",
        "caste",
        "tour",
        "sAtte",
        "cAlle",
        "I",
        "Atin",
        "hAL",
    ],
    "name2_col2": [
        "ville",
        "val",
        "blAc",
        "mont",
        "court",
        "menil",
        "chatel",
        "vast",
        "bec",
        "dalle",
        "tuit",
        "fleur",
        "lan",
    ],
    "name2_prefixes": ["d'", "de ", "du "],
    "transformations": [
        {"input": "A", "outputs": ["a", "e", "i", "o", "u"]},
        {"input": "I", "outputs": ["e", "a", "i"]},
        {"input": "N", "outputs": ["n", "m"]},
        {"input": "L", "outputs": ["l", "r"]},
        {"input": "B", "outputs": ["l", "r", "m", "n", "c", "ch", "v", "s"]},
    ],
}

compound_tables: t.Dict[str, t.List] = {
    "nature_col1": [
        "green",
        "mist",
        "willow",
        "dream",
        "dusk",
        "night",
        "sage",
        "green",
        "dew",
        "high",
        "bright",
        "cliff",
        "hawk",
        "wind",
        "rain",
        "shadow",
        "sun",
        "cloud",
        "storm",
    ],
    "nature_col2": [
        "wood",
        "shade",
        "glade",
        "blossom",
        "wing",
        "vale",
        "grove",
        "thorn",
        "bark",
        "grass",
        "song",
        "weave",
        "heart",
        "whisper",
        "hunter",
        "root",
    ],
    "mountain_col1": [
        "shield",
        "deep",
        "dark",
        "steel",
        "heavy",
        "grim",
        "dim",
        "stout",
        "battle",
        "iron",
        "stone",
        "dust",
        "mountain",
        "strong",
        "great",
        "proud",
        "brave",
        "gravel",
    ],
    "mountain_col2": [
        "scream",
        "rage",
        "grip",
        "brew",
        "mail",
        "blaze",
        "strike",
        "helm",
        "spear",
        "beard",
        "fury",
        "break",
        "hammer",
        "brow",
        "cask",
        "mace",
        "mead",
        "pike",
        "pick",
    ],
    "generic_col1": [
        "ash",
        "swift",
        "cold",
        "gold",
        "silk",
        "dragon",
        "red",
        "lion",
        "glory",
        "black",
        "blue",
        "hell",
        "demon",
        "fire",
        "wine",
    ],
    "generic_col2": [
        "bane",
        "scar",
        "mark",
        "shine",
        "stride",
        "brand",
        "river",
        "rider",
        "crest",
        "blade",
        "bluff",
        "blood",
        "cloak",
        "born",
        "sworn",
        "fist",
        "ship",
        "arm",
        "gaze",
    ],
}



from fantasynames.data import dwarf_data, compound_tables
from fantasynames.language import Language


class Dwarf(Language):
    transformations = dwarf_data["transformations"]

    @classmethod
    def _name1_male(cls) -> str:
        cols = [dwarf_data["name1_col1"], dwarf_data["name1_col2"]]
        return cls._name_from_lists(cols)

    @classmethod
    def _name1_female(cls) -> str:
        name = cls._name1_male() + cls._name_from_lists([dwarf_data["name1_suffixes"]])
        return name

    @classmethod
    def _name2(cls) -> str:
        cols = [compound_tables["mountain_col1"], compound_tables["mountain_col2"]]
        name = cls._name_from_lists(cols)
        return name


dwarf = Dwarf.name



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fantasynames']

package_data = \
{'': ['*']}

install_requires = \
['black>=20.8b1,<21.0', 'flake8>=3.9.0,<4.0.0', 'mypy>=0.812,<0.813']

setup_kwargs = {
    'name': 'fantasynames',
    'version': '0.1.1',
    'description': 'A fantasy themed random name generator.',
    'long_description': '# Fantasy Name Generator\n\n[![PyPI version](https://badge.fury.io/py/fantasynames.svg)](https://badge.fury.io/py/fantasynames)\n\nA random name generator that produces names aligning (more or less) with common conventions for fantasy characters in fictional media such as Dungeons and Dragons or World of Warcraft.\n\n## Installation\n\n`python3 -m pip install fantasynames`\n\n## Usage\n\nThe following name generating functions are provided for a variety of different stereotypical fantasy "races", as well as a few different "medieval-y" languages:\n\n```python\nimport fantasynames as names\n\nnames.elf()\n# Example outputs: \'Farathia Eaviel\', \'Iethian Willowblossom\'\n\nnames.dwarf()\n# Example outputs: \'Thrunnor Ironfury\', \'Lothuna Strongmail\'\n\nnames.hobbit()\n# Example outputs: \'Libby Honeyfoot\', \'Flublius Sweetscone\'\n\nnames.french()\n# Example outputs: \'Auland Roublac\', \'Rondri de Clardalle\'\n\nnames.anglo()\n# Example outputs: \'Brandin of Avonlyn\', \'Kallem Davenmere\'\n\nnames.human()\n# Example outputs: \'Danric du Tourbloc\', \'Sumia Sageholme\'\n```\n\nNote that `human()` provides a diverse mix of different first and last name styles, including `anglo()` and `french()`...and more!\n\nYou can also pass a string argument to specify whether you want to recieve masculine or feminine names. By default, it\'s totally random:\n\n```python\nnames.human() # this will randomly generate either a male or female name\n\nnames.human(\'any\') # this is equivalent to the above, in case you want to be specific\n\nnames.human(\'male\') # this will generate a masculine name\n\nnames.human(\'female\') # this will generate a feminine name\n```\n\n## Contributing\n\n### Poetry\n\nThis package uses [Poetry](https://python-poetry.org/) for package management. After checking out the repo, use `poetry install` to install all the required dependencies. Anytime you need to add a package, use:\n\n```\npoetry add <PACKAGE_NAME_HERE>\n```\n\n### Linting / Formatting\n\nWe do code formatting with [Python Black](https://github.com/psf/black), other linting with `flake8`, and type checking with `mypy`. Before opening a PR, please make sure to run all of these. Below is a helpful command to do them all at once:\n\n```\npoetry run black fantasynames && poetry run flake8 fantasynames && poetry run mypy fantasynames\n```\n\n### Guides\n\nFor guides on how to make your own name generators, check out the [How to Add a New Name Generator Guide](docs/new-generator-guide.md). And then if you want to ramp up the complexity, take a look at the [Transformation Guide](docs/transformation-guide.md).\n',
    'author': 'Jessica Peck',
    'author_email': 'jessypeck@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/jessypeck/fantasynames',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
